# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/10_logr.ipynb.

# %% auto 0
__all__ = ['ArgsType', 'SysExcInfoType', 'FormatStyle']

# %% ../nbs/10_logr.ipynb 6
import inspect

# %% ../nbs/10_logr.ipynb 8
from types import TracebackType
from typing import Any, Mapping, Literal, TypeAlias

# %% ../nbs/10_logr.ipynb 10
#| export


# %% ../nbs/10_logr.ipynb 12
#| export


# %% ../nbs/10_logr.ipynb 14
#| export


# %% ../nbs/10_logr.ipynb 16
ArgsType: TypeAlias = type[tuple[object, ...]] | type[Mapping[str, object]]

SysExcInfoType: TypeAlias = \
    type[tuple[type[BaseException], BaseException, TracebackType | None]] | \
    type[tuple[None, None, None]]

FormatStyle: TypeAlias = Literal['%', '{', '$']
