# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/05_enum.ipynb.

# %% auto 0
__all__ = ['Intum', 'Strum', 'Inhum']

# %% ../nbs/05_enum.ipynb 6
from enum import IntEnum, StrEnum

# %% ../nbs/05_enum.ipynb 8
from typing import (
    TypeAlias, Literal, Union, List, Set,
    Iterable, Tuple, ForwardRef
)

# %% ../nbs/05_enum.ipynb 10
#| export


# %% ../nbs/05_enum.ipynb 12
#| export


# %% ../nbs/05_enum.ipynb 14
#| export


# %% ../nbs/05_enum.ipynb 16
Intum: TypeAlias = Union[IntEnum, 'LitIntEnum', 'Intum']
Strum: TypeAlias = Union[StrEnum, 'LitStrEnum', 'Strum', 'LiteralEnum']

Inhum = ForwardRef('Inhum', module='inhum', is_class=True)
