# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/07_type.ipynb.

# %% auto 0
__all__ = ['Literals', 'TypingLike', 'GuardLike', 'Module']

# %% ../nbs/07_type.ipynb 6
#| export


# %% ../nbs/07_type.ipynb 8
import types
from typing import (
    TypeAlias, Literal, Union, List, Set,
    Iterable, Tuple, ForwardRef, TypeVar, TypeGuard
)

# %% ../nbs/07_type.ipynb 10
#| export


# %% ../nbs/07_type.ipynb 12
#| export


# %% ../nbs/07_type.ipynb 14
#| export


# %% ../nbs/07_type.ipynb 17
Literals = TypeVar('Literals')
TypingLike: TypeAlias = Union['TTyp', 'TType', 'TypingUnit', 'Typing']
GuardLike: TypeAlias = Union['TTypGuard', 'TTypeGuard']

# %% ../nbs/07_type.ipynb 19
Module: TypeAlias = types.ModuleType
