# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/atyp',
                'doc_host': 'https://dsm-72.github.io',
                'git_url': 'https://github.com/dsm-72/atyp',
                'lib_path': 'atyp'},
  'syms': { 'atyp.biol': {},
            'atyp.bool': {'atyp.bool.Bool01': ('bool.html#bool01', 'atyp/bool.py')},
            'atyp.byte': {},
            'atyp.clsv': {},
            'atyp.cstm': {},
            'atyp.enum': {},
            'atyp.imgs': {},
            'atyp.imps': {},
            'atyp.insp': {},
            'atyp.iter': {},
            'atyp.list': {},
            'atyp.logr': {},
            'atyp.npty': {},
            'atyp.nums': {},
            'atyp.path': {},
            'atyp.pdty': { 'atyp.pdty.BoolIndex': ('pdty.html#boolindex', 'atyp/pdty.py'),
                           'atyp.pdty.IndexLike': ('pdty.html#indexlike', 'atyp/pdty.py'),
                           'atyp.pdty.SeriesLike': ('pdty.html#serieslike', 'atyp/pdty.py')},
            'atyp.plot': {},
            'atyp.rich': {},
            'atyp.sets': {},
            'atyp.spty': {},
            'atyp.strs': { 'atyp.strs.NotStrBytes': ('strs.html#notstrbytes', 'atyp/strs.py'),
                           'atyp.strs.StrBytes': ('strs.html#strbytes', 'atyp/strs.py')},
            'atyp.tens': {},
            'atyp.tgrd': {},
            'atyp.tqdm': {},
            'atyp.type': {},
            'atyp.typq': {},
            'atyp.typr': {}}}
