# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/06_byte.ipynb.

# %% auto 0
__all__ = ['ByteLike']

# %% ../nbs/06_byte.ipynb 6
#| export


# %% ../nbs/06_byte.ipynb 8
from typing import (
    TypeAlias, Literal, Union, List, Set,
    Iterable, Tuple, ForwardRef
)

# %% ../nbs/06_byte.ipynb 10
#| export


# %% ../nbs/06_byte.ipynb 12
#| export


# %% ../nbs/06_byte.ipynb 14
#| export


# %% ../nbs/06_byte.ipynb 16
ByteLike: TypeAlias = Union[bytes, 'BytesUnit', 'Bytes']
