# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/50_rich.ipynb.

# %% auto 0
__all__ = ['RichTree', 'RichText', 'RichCons', 'RichProg']

# %% ../nbs/50_rich.ipynb 6
import inspect

# %% ../nbs/50_rich.ipynb 8
import types
from typing import (
    Type, TypeAlias, 
    ClassVar, Any, Optional, Callable, Iterable, ForwardRef
)
from numbers import Number

# %% ../nbs/50_rich.ipynb 10
try:
    from rich.tree import Tree
    from rich.text import Text
    from rich.console import Console
    from rich.progress import Progress
    tree = Tree
    text = Text
    cons = Console
    prog = Progress
    
except ImportError:
    tree = ForwardRef('rich.tree.Tree', module='rich.tree', is_class=True)
    text = ForwardRef('rich.text.Text', module='rich.text', is_class=True)
    cons = ForwardRef('rich.console.Console', module='rich.console', is_class=True)
    prog = ForwardRef('rich.progress.Progress', module='rich.progress', is_class=True)

# %% ../nbs/50_rich.ipynb 12
#| export


# %% ../nbs/50_rich.ipynb 14
#| export


# %% ../nbs/50_rich.ipynb 16
RichTree: TypeAlias = tree
RichText: TypeAlias = text
RichCons: TypeAlias = cons
RichProg: TypeAlias = prog
