# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/110_spty.ipynb.

# %% auto 0
__all__ = ['SPArray', 'SPMatrix']

# %% ../nbs/110_spty.ipynb 6
#| export


# %% ../nbs/110_spty.ipynb 8
from typing import TypeAlias

# %% ../nbs/110_spty.ipynb 11
try:
    import scipy as sp
    
    try: sparr = sp.sparse._arrays._sparray
    except AttributeError: sparr = sp.sparse.sparray

    spmtx = sp.sparse.spmatrix

except ImportError:
    # Define a placeholder type if scipy is not installed
    sparr = 'scipy.sparse._base.sparray'
    spmtx = 'scipy.sparse._matrix.spmatrix'

# %% ../nbs/110_spty.ipynb 13
#| export


# %% ../nbs/110_spty.ipynb 15
#| export


# %% ../nbs/110_spty.ipynb 18
SPArray: TypeAlias = sparr
SPMatrix: TypeAlias = spmtx
