# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/90_cstm.ipynb.

# %% auto 0
__all__ = ['PathFormatFunc', 'Mixin']

# %% ../nbs/90_cstm.ipynb 6
import os
from numbers import Number

# %% ../nbs/90_cstm.ipynb 8
from typing import (Type, Union, Tuple, TypeAlias, Callable)

# %% ../nbs/90_cstm.ipynb 10
#| export


# %% ../nbs/90_cstm.ipynb 12
#| export


# %% ../nbs/90_cstm.ipynb 14
from .bool import Boolish
from .nums import Numeric
from .typq import AnyQ, StrQ

# %% ../nbs/90_cstm.ipynb 16
PathFormatFunc: TypeAlias = Callable[[os.PathLike, StrQ, StrQ, StrQ], str]

# %% ../nbs/90_cstm.ipynb 18
Mixin: TypeAlias =  Union[Tuple[Type, Callable], 'MixinType']
