# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/50_tqdm.ipynb.

# %% auto 0
__all__ = ['TQDM']

# %% ../nbs/50_tqdm.ipynb 6
#| export


# %% ../nbs/50_tqdm.ipynb 8
from typing import (TypeAlias, ForwardRef)

# %% ../nbs/50_tqdm.ipynb 10
try: 
    from tqdm.auto import tqdm as auto    
except ImportError: 
    auto = ForwardRef('tqdm.auto.tqdm', module='tqdm.auto', is_class=True)

# %% ../nbs/50_tqdm.ipynb 12
#| export


# %% ../nbs/50_tqdm.ipynb 14
#| export


# %% ../nbs/50_tqdm.ipynb 16
TQDM: TypeAlias = auto
