# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/51_typr.ipynb.

# %% auto 0
__all__ = ['TyperApp']

# %% ../nbs/51_typr.ipynb 6
import inspect

# %% ../nbs/51_typr.ipynb 8
import types
from typing import (
    Type, TypeAlias, 
    ClassVar, Any, Optional, Callable, Iterable, ForwardRef
)
from numbers import Number

# %% ../nbs/51_typr.ipynb 10
try:
    from typer import Typer
    tapp = Typer    
except ImportError:
    tapp = ForwardRef('typer.Typer', module='typer', is_class=True)

# %% ../nbs/51_typr.ipynb 12
#| export


# %% ../nbs/51_typr.ipynb 14
#| export


# %% ../nbs/51_typr.ipynb 16
TyperApp: TypeAlias = tapp
