# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/51_plot.ipynb.

# %% auto 0
__all__ = ['Axes', 'ColorMap', 'CBarPos']

# %% ../nbs/51_plot.ipynb 6
import inspect

# %% ../nbs/51_plot.ipynb 8
import types
from typing import (
    Type, TypeAlias, Tuple,
    ClassVar, Any, Optional, Callable, Iterable, ForwardRef
)
from numbers import Number

# %% ../nbs/51_plot.ipynb 10
try:
    import matplotlib as mpl
    from matplotlib.axes._axes import Axes

    cmap = mpl.colors.Colormap
    axes = Axes

except ImportError:
    cmap = 'matplotlib.colors.Colormap'
    axes = 'matplotlib.axes._axes.Axes'

# %% ../nbs/51_plot.ipynb 12
#| export


# %% ../nbs/51_plot.ipynb 14
#| export


# %% ../nbs/51_plot.ipynb 16
Axes: TypeAlias = axes
ColorMap: TypeAlias = cmap

# CBarPos: tuple of (left, bottom, width, height)
CBarPos: TypeAlias = Tuple[float, float, float, float]
