# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/41_list.ipynb.

# %% auto 0
__all__ = ['ListStr', 'ListNum', 'ListBool', 'Strs', 'Nums', 'Bools']

# %% ../nbs/41_list.ipynb 6
import inspect

# %% ../nbs/41_list.ipynb 8
from typing import (TypeAlias, List)

# %% ../nbs/41_list.ipynb 10
#| export


# %% ../nbs/41_list.ipynb 12
#| export


# %% ../nbs/41_list.ipynb 14
from .bool import Boolish
from .nums import Numeric

# %% ../nbs/41_list.ipynb 16
ListStr: TypeAlias = List[str]
ListNum: TypeAlias = List[Numeric]
ListBool: TypeAlias = List[Boolish]


Strs: TypeAlias = ListStr
Nums: TypeAlias = ListNum
Bools: TypeAlias = ListBool
