# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/30_clsv.ipynb.

# %% auto 0
__all__ = ['ClsInt', 'ClsSet', 'ClsStr', 'ClsObj', 'ClsBool', 'ClsBoolish', 'ClsCall', 'ClsType', 'ClsList', 'ClsFloat',
           'ClsNumber', 'ClsComplex']

# %% ../nbs/30_clsv.ipynb 6
import inspect

# %% ../nbs/30_clsv.ipynb 8
import types
from typing import (
    TypeAlias, Literal, Union, List, Set,
    Iterable, Tuple, ForwardRef, TypeVar, TypeGuard
)
from typing import (ClassVar, Callable)

# %% ../nbs/30_clsv.ipynb 10
#| export


# %% ../nbs/30_clsv.ipynb 12
#| export


# %% ../nbs/30_clsv.ipynb 14
from .bool import Boolish
from .nums import Numeric

# %% ../nbs/30_clsv.ipynb 16
ClsInt = ClassVar[int]
ClsSet = ClassVar[set]
ClsStr = ClassVar[str]
ClsObj = ClassVar[object]

ClsBool = ClassVar[bool]
ClsBoolish = ClassVar[Boolish]
ClsCall = ClassVar[Callable]

ClsType = ClassVar[type]
ClsList = ClassVar[list]

ClsFloat = ClassVar[float]
ClsNumber = ClassVar[Numeric]
ClsComplex = ClassVar[complex]
