# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/03_strs.ipynb.

# %% auto 0
__all__ = ['StrTmpl', 'StrLike', 'Pttn', 'PttnDict', 'StrBytes', 'NotStrBytes']

# %% ../nbs/03_strs.ipynb 6
import re
from string import Template

# %% ../nbs/03_strs.ipynb 8
from typing import (TypeAlias, Union, Dict)

# %% ../nbs/03_strs.ipynb 10
#| export


# %% ../nbs/03_strs.ipynb 12
from ptyp import Alias, Not

# %% ../nbs/03_strs.ipynb 14
#| export


# %% ../nbs/03_strs.ipynb 16
StrTmpl: TypeAlias = Union[str, Template]
StrLike: TypeAlias = Union[str, 'strfix', 'fuzstr', 'nymstr', 'synset', 'brvstr', 'strfix']

# %% ../nbs/03_strs.ipynb 18
Pttn: TypeAlias = re.Pattern
PttnDict: TypeAlias = Dict[str, Pttn]

# %% ../nbs/03_strs.ipynb 19
@Alias(str, bytes)
class StrBytes: ...

@Not(str, bytes)
class NotStrBytes: ...
