# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/08_imps.ipynb.

# %% auto 0
__all__ = ['Loader', 'ModuleSpec']

# %% ../nbs/08_imps.ipynb 6
import importlib
from importlib.abc import Loader

# %% ../nbs/08_imps.ipynb 8
import types
from typing import (
    TypeAlias, Literal, Union, List, Set,
    Iterable, Tuple, ForwardRef, TypeVar, TypeGuard
)

# %% ../nbs/08_imps.ipynb 10
#| export


# %% ../nbs/08_imps.ipynb 12
#| export


# %% ../nbs/08_imps.ipynb 14
#| export


# %% ../nbs/08_imps.ipynb 16
Loader: TypeAlias = Loader
ModuleSpec: TypeAlias = importlib.machinery.ModuleSpec
