# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/09_insp.ipynb.

# %% auto 0
__all__ = ['Sig', 'Param']

# %% ../nbs/09_insp.ipynb 6
import inspect

# %% ../nbs/09_insp.ipynb 8
import types
from typing import (
    TypeAlias, Literal, Union, List, Set,
    Iterable, Tuple, ForwardRef, TypeVar, TypeGuard
)

# %% ../nbs/09_insp.ipynb 10
#| export


# %% ../nbs/09_insp.ipynb 12
#| export


# %% ../nbs/09_insp.ipynb 14
#| export


# %% ../nbs/09_insp.ipynb 16
Sig:   TypeAlias = inspect.Signature
Param: TypeAlias = inspect.Parameter
