# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/02_nums.ipynb.

# %% auto 0
__all__ = ['Numeric', 'Numbers', 'NumStr']

# %% ../nbs/02_nums.ipynb 6
from numbers import Number

# %% ../nbs/02_nums.ipynb 8
from typing import (TypeAlias, Union, List,)

# %% ../nbs/02_nums.ipynb 10
#| export


# %% ../nbs/02_nums.ipynb 12
#| export


# %% ../nbs/02_nums.ipynb 14
#| export


# %% ../nbs/02_nums.ipynb 16
Numeric: TypeAlias = Union[int, float, complex, Number]
Numbers: TypeAlias = List[Numeric]
NumStr: TypeAlias = Union[Numeric, str]
