# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/53_biol.ipynb.

# %% auto 0
__all__ = ['Adata', 'Adatas', 'AnnData', 'AnnDatas']

# %% ../nbs/53_biol.ipynb 6
import inspect
from numbers import Number

# %% ../nbs/53_biol.ipynb 8
import types
from typing import (
    Type, TypeAlias, Tuple,
    ClassVar, Any, Optional, Callable, Iterable, ForwardRef
)
from typing import TypeAlias, List, Union, Iterable, List

# %% ../nbs/53_biol.ipynb 11
try:
    import anndata as ad
    adata  = ad.AnnData
    adatas = List[adata]
except ImportError:
    # Define a placeholder type if anndata is not installed
    adata = 'anndata.AnnData'
    adatas = List[adata]

# %% ../nbs/53_biol.ipynb 13
#| export


# %% ../nbs/53_biol.ipynb 15
from .nums import Numbers

# %% ../nbs/53_biol.ipynb 18
Adata: TypeAlias = adata
Adatas: TypeAlias = adatas

AnnData: TypeAlias = adata
AnnDatas: TypeAlias = adatas
