# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/40_iter.ipynb.

# %% auto 0
__all__ = ['IterStr', 'IterNum', 'IterBool']

# %% ../nbs/40_iter.ipynb 6
#| export


# %% ../nbs/40_iter.ipynb 8
from typing import (TypeAlias, Iterable, )

# %% ../nbs/40_iter.ipynb 10
#| export


# %% ../nbs/40_iter.ipynb 12
#| export


# %% ../nbs/40_iter.ipynb 14
from .bool import Boolish
from .nums import Numeric

# %% ../nbs/40_iter.ipynb 16
IterStr: TypeAlias = Iterable[str]
IterNum: TypeAlias = Iterable[Numeric]
IterBool: TypeAlias = Iterable[Boolish]
