# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/42_sets.ipynb.

# %% auto 0
__all__ = ['SetStr', 'SetNum', 'SetBool']

# %% ../nbs/42_sets.ipynb 6
import inspect

# %% ../nbs/42_sets.ipynb 8
from typing import (TypeAlias, Set)

# %% ../nbs/42_sets.ipynb 10
#| export


# %% ../nbs/42_sets.ipynb 12
#| export


# %% ../nbs/42_sets.ipynb 14
from .bool import Boolish
from .nums import Numeric

# %% ../nbs/42_sets.ipynb 16
SetStr: TypeAlias = Set[str]
SetNum: TypeAlias = Set[Numeric]
SetBool: TypeAlias = Set[Boolish]
